AnalyticsData class abstract

Install analytics data from the formulae.brew.sh API.

Annotations
  • @freezed

Constructors

AnalyticsData({required String category, @JsonKey.new(name: 'total_items') required int totalItems, @JsonKey.new(name: 'start_date') required String startDate, @JsonKey.new(name: 'end_date') required String endDate, @JsonKey.new(name: 'total_count') required int totalCount, required Map<String, int> items})
const
factory
AnalyticsData.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited