CaskSummary class abstract

Summary of a cask from the formulae.brew.sh catalog API.

Returned by GET /api/cask.json.

Available extensions
Annotations
  • @freezed

Constructors

CaskSummary({required String token, @JsonKey.new(name: 'full_token') String? fullToken, String? tap, List<String>? name, required String desc, required String homepage, required String version, @Default.new(false) bool deprecated, @Default.new(false) bool disabled})
const
factory
CaskSummary.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $CaskSummaryCopyWith<CaskSummary>
Create a copy of CaskSummary with the given fields replaced by the non-null parameter values.
no setterinherited
deprecated bool
no setterinherited
desc String
no setterinherited
disabled bool
no setterinherited
fullToken String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
homepage String
no setterinherited
name List<String>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tap String?
no setterinherited
token String
no setterinherited
version String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CaskSummary value)) → TResult

Available on CaskSummary, provided by the CaskSummaryPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CaskSummary value)?) → TResult?

Available on CaskSummary, provided by the CaskSummaryPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CaskSummary value)?, {required TResult orElse()}) → TResult

Available on CaskSummary, provided by the CaskSummaryPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String token, String? fullToken, String? tap, List<String>? name, String desc, String homepage, String version, bool deprecated, bool disabled)?, {required TResult orElse()}) → TResult

Available on CaskSummary, provided by the CaskSummaryPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CaskSummary to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String token, String? fullToken, String? tap, List<String>? name, String desc, String homepage, String version, bool deprecated, bool disabled)) → TResult

Available on CaskSummary, provided by the CaskSummaryPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String token, String? fullToken, String? tap, List<String>? name, String desc, String homepage, String version, bool deprecated, bool disabled)?) → TResult?

Available on CaskSummary, provided by the CaskSummaryPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited