FormulaSummary class abstract
Summary of a formula from the formulae.brew.sh catalog API.
Returned by GET /api/formula.json.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
FormulaSummary({required String name, @JsonKey.new(name: 'full_name') required String fullName, String? tap, required String desc, String? license, required String homepage, @JsonKey.new(name: 'versions') required Map<
String, dynamic> versions, @Default.new(false) bool deprecated, @Default.new(false) bool disabled}) -
constfactory
-
FormulaSummary.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $FormulaSummaryCopyWith<
FormulaSummary> -
Create a copy of FormulaSummary
with the given fields replaced by the non-null parameter values.
no setterinherited
- deprecated → bool
-
no setterinherited
- desc → String
-
no setterinherited
- disabled → bool
-
no setterinherited
- fullName → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- homepage → String
-
no setterinherited
- license → String?
-
no setterinherited
- name → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tap → String?
-
no setterinherited
-
versions
→ Map<
String, dynamic> -
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_FormulaSummary value)) → TResult -
Available on FormulaSummary, provided by the FormulaSummaryPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_FormulaSummary value)?) → TResult? -
Available on FormulaSummary, provided by the FormulaSummaryPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_FormulaSummary value)?, {required TResult orElse()}) → TResult -
Available on FormulaSummary, provided by the FormulaSummaryPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String name, String fullName, String? tap, String desc, String? license, String homepage, Map< String, dynamic> versions, bool deprecated, bool disabled)?, {required TResult orElse()}) → TResult -
Available on FormulaSummary, provided by the FormulaSummaryPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this FormulaSummary to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String name, String fullName, String? tap, String desc, String? license, String homepage, Map< String, dynamic> versions, bool deprecated, bool disabled)) → TResult -
Available on FormulaSummary, provided by the FormulaSummaryPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String name, String fullName, String? tap, String desc, String? license, String homepage, Map< String, dynamic> versions, bool deprecated, bool disabled)?) → TResult? -
Available on FormulaSummary, provided by the FormulaSummaryPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited