CaskDetail class abstract
Detailed cask info from the formulae.brew.sh API.
Returned by GET /api/cask/{name}.json.
- Annotations
-
- @freezed
Constructors
-
CaskDetail({required String token, @JsonKey.new(name: 'full_token') String? fullToken, String? tap, List<
String> ? name, required String desc, required String homepage, required String version, String? url, String? sha256, @JsonKey.new(name: 'depends_on') Map<String, dynamic> ? dependsOn, List<String> ? conflicts, @JsonKey.new(name: 'auto_updates') bool? autoUpdates, @Default.new(false) bool deprecated, @Default.new(false) bool disabled, Map<String, dynamic> ? analytics, @JsonKey.new(name: 'generated_date') String? generatedDate}) -
constfactory
-
CaskDetail.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited