CaskSummary class abstract
Summary of a cask from the formulae.brew.sh catalog API.
Returned by GET /api/cask.json.
- Annotations
-
- @freezed
Constructors
-
CaskSummary({required String token, @JsonKey.new(name: 'full_token') String? fullToken, String? tap, List<
String> ? name, required String desc, required String homepage, required String version, @Default.new(false) bool deprecated, @Default.new(false) bool disabled}) -
constfactory
-
CaskSummary.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited