FormulaDetail class abstract
Detailed formula info from the formulae.brew.sh API.
Returned by GET /api/formula/{name}.json.
This is the full JSON v2-style object for a single formula.
- Annotations
-
- @freezed
Constructors
-
FormulaDetail({required String name, @JsonKey.new(name: 'full_name') required String fullName, String? tap, required String desc, String? license, required String homepage, required Map<
String, dynamic> versions, @Default.new([]) List<String> dependencies, @JsonKey.new(name: 'build_dependencies') @Default.new([]) List<String> buildDependencies, @JsonKey.new(name: 'optional_dependencies') @Default.new([]) List<String> optionalDependencies, @JsonKey.new(name: 'keg_only') @Default.new(false) bool kegOnly, @Default.new(false) bool deprecated, @Default.new(false) bool disabled, Map<String, dynamic> ? analytics, @JsonKey.new(name: 'analytics_linux') Map<String, dynamic> ? analyticsLinux, @JsonKey.new(name: 'generated_date') String? generatedDate}) -
constfactory
-
FormulaDetail.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited