FormulaSummary class abstract
Summary of a formula from the formulae.brew.sh catalog API.
Returned by GET /api/formula.json.
- Annotations
-
- @freezed
Constructors
-
FormulaSummary({required String name, @JsonKey.new(name: 'full_name') required String fullName, String? tap, required String desc, String? license, required String homepage, @JsonKey.new(name: 'versions') required Map<
String, dynamic> versions, @Default.new(false) bool deprecated, @Default.new(false) bool disabled}) -
constfactory
-
FormulaSummary.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited