HttpGetFn typedef
Function type for making HTTP GET requests.
This abstraction allows consumers to provide their own HTTP client
(e.g. package:http, package:dio, or dart:io HttpClient) without
this package depending on any specific HTTP library.
The function should return the response body as a String. It should throw on non-2xx status codes.
Implementation
typedef HttpGetFn = Future<String> Function(Uri url);